/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEGATEXSETENFORCE_H
#define SEGATEXSETENFORCE_H

#include <QTextEdit>

#include <selinux/selinux.h>
#include <selinux/get_default_type.h>

class QTextEdit;
class MainWindow;

class SegatexSetenforce: public QTextEdit
{
	Q_OBJECT
public:
	SegatexSetenforce(QWidget *parent = 0, const char *name = 0);
    
public slots:
signals:
	void sestateChanged();
protected:

private slots:
	int setenforce_enforce();
	int setenforce_permissive();
private:
	int return_value;
	MainWindow *mainWindow;
};

#endif
